@@ -48,7 +48,7 @@ impl<I: Iterator> Files<I> {
     }
 }
 
-struct Line<'a>(&'a [u8], u64);
+pub struct Line<'a>(pub &'a [u8], pub u64);
 struct Lines<'a> {
     lnum: usize,
     prev: usize,
@@ -56,7 +56,7 @@ struct Lines<'a> {
     iter: Memchr<'a>,
 }
 impl<'a> Lines<'a> {
-    fn new(buf: &'a [u8]) -> Self {
+    pub fn new(buf: &'a [u8]) -> Self {
         Self {
             lnum: 1,
             prev: 0,
